"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import categorisedaccount as shared_categorisedaccount
from ..shared import confirmcategories as shared_confirmcategories
from typing import Optional


@dataclasses.dataclass
class UpdateAccountsCategoriesRequest:
    
    company_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'companyId', 'style': 'simple', 'explode': False }})
    connection_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'connectionId', 'style': 'simple', 'explode': False }})
    confirm_categories: Optional[shared_confirmcategories.ConfirmCategories] = dataclasses.field(default=None, metadata={'request': { 'media_type': 'application/json' }})
    

@dataclasses.dataclass
class UpdateAccountsCategoriesResponse:
    
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    categorised_accounts: Optional[list[shared_categorisedaccount.CategorisedAccount]] = dataclasses.field(default=None)
    r"""OK"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    