"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import excelreporttype as shared_excelreporttype
from ..shared import excelstatus as shared_excelstatus
from typing import Optional


@dataclasses.dataclass
class GenerateExcelReportRequest:
    
    company_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'companyId', 'style': 'simple', 'explode': False }})
    report_type: shared_excelreporttype.ExcelReportType = dataclasses.field(metadata={'query_param': { 'field_name': 'reportType', 'style': 'form', 'explode': True }})
    r"""The type of report you want to generate and download."""
    

@dataclasses.dataclass
class GenerateExcelReportResponse:
    
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    excel_status: Optional[shared_excelstatus.ExcelStatus] = dataclasses.field(default=None)
    r"""OK"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    