"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class IntegrityStatus(str, Enum):
    r"""The current status of the most recently run matching algorithm."""
    UNKNOWN = 'Unknown'
    DOES_NOT_EXIST = 'DoesNotExist'
    ERROR = 'Error'
    COMPLETE = 'Complete'
