"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import categorisedaccount as shared_categorisedaccount
from ..shared import confirmcategory as shared_confirmcategory
from typing import Optional


@dataclasses.dataclass
class UpdateAccountCategoryRequest:
    
    account_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'accountId', 'style': 'simple', 'explode': False }})
    r"""Nominal account id"""
    company_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'companyId', 'style': 'simple', 'explode': False }})
    connection_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'connectionId', 'style': 'simple', 'explode': False }})
    confirm_category: Optional[shared_confirmcategory.ConfirmCategory] = dataclasses.field(default=None, metadata={'request': { 'media_type': 'application/json' }})
    

@dataclasses.dataclass
class UpdateAccountCategoryResponse:
    
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    categorised_account: Optional[shared_categorisedaccount.CategorisedAccount] = dataclasses.field(default=None)
    r"""OK"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    